==> mdl-1.12.2.tar.gz: README.md <==
# Material Design Lite for Dart
> A GUI library and framework to develop web apps in Dart.  

[www.material-design-lite.pub](http://www.material-design-lite.pub).

Material Design Lite lets you add a Material Design look and feel to your dynamic websites and web app. It doesn't rely on any JavaScript
frameworks or libraries. Optimised for cross-device use, gracefully degrades in older browsers, and offers an experience that is accessible
from the get-go.

## New
v 1.11 - MDLFlux (REACT-like Actions, ActionBus, Dispatcher and DataStore)

You can see further changes on the [CHANGELOG](https://github.com/MikeMitterer/dart-material-design-lite/blob/master/CHANGELOG.md)!

![MDLFlux](doc/libs/flux/mdlFlux.png?raw=true "MDLFlux message flow")

## Main features
- 16 base components ready to use
- 4 different Dialogs, AlertDialog, ConfirmDialog, Notification-Messages and Snackbar
- [Directives](http://styleguide.material-design-lite.pub/#/attribute)
- Drag and Drop
- Formatters
- Mustache-Based Components (Template based)
- Nice, ready to use, templates
- [Single Page Application](http://samples.material-design-lite.pub/template_spa/index.html)
- Routing
- Dependency injection
- [Samples, samples, samples](http://styleguide.material-design-lite.pub/#/samples)
- Theming

Visit the [website](http://www.material-design-lite.pub) for a "Quick start" or check out the [Kitchen Sink](http://styleguide.material-design-lite.pub/)

## Examples
Check out the [samples](http://styleguide.material-design-lite.pub/#/samples)

### IMPORTANT!!!
All samples-sources are now on [GH dart-material-design-lite-site](https://github.com/MikeMitterer/dart-material-design-lite-site)

## Features and bugs
Please file feature requests and bugs at the [issue tracker](https://github.com/MikeMitterer/dart-material-design-lite/issues).

## More links
- [Material Design](http://www.google.com/design/spec/material-design/introduction.html)

###License###

    Copyright 2015 Michael Mitterer (office@mikemitterer.at),
    IT-Consulting and Development Limited, Austrian Branch

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    either express or implied. See the License for the specific language
    governing permissions and limitations under the License.


If this plugin is helpful for you - please [(Circle)](http://gplus.mikemitterer.at/) me
or **star** this repo here on GitHub


[tracker]: https://github.com/MikeMitterer/dart-material-design-lite/issues
[mdlmaterial]: https://github.com/MikeMitterer/dart-material-design-lite
[mdldemo]: http://www.material-design-lite.pub
[mdlangular]: https://github.com/MikeMitterer/dart-mdl-angular
[samples]: https://github.com/MikeMitterer/dart-material-design-lite/tree/mdl/example
[promoimage]: https://github.com/MikeMitterer/dart-material-design-lite/blob/master/lib/images/mdl.mikemitterer.at-720px.jpg?raw=true

==> mdl-1.14.0.tar.gz: README.md <==
# Material Design Lite for Dart
> A GUI library and framework to develop web apps in Dart.  

[www.material-design-lite.pub](http://www.material-design-lite.pub).

Material Design Lite lets you add a Material Design look and feel to your dynamic websites and web app. It doesn't rely on any JavaScript
frameworks or libraries. Optimised for cross-device use, gracefully degrades in older browsers, and offers an experience that is accessible
from the get-go.

## New
v 1.11 - MDLFlux (REACT-like Actions, ActionBus, Dispatcher and DataStore)

You can see further changes on the [CHANGELOG](https://github.com/MikeMitterer/dart-material-design-lite/blob/master/CHANGELOG.md)!

![MDLFlux](https://github.com/MikeMitterer/dart-material-design-lite/blob/master/doc/libs/flux/mdlFlux.png?raw=true "MDLFlux message flow")

## Main features
- 16 base components ready to use
- 4 different Dialogs, AlertDialog, ConfirmDialog, Notification-Messages and Snackbar
- [Directives](http://styleguide.material-design-lite.pub/#/attribute)
- Drag and Drop
- Formatters
- Mustache-Based Components (Template based)
- Nice, ready to use, templates
- [Single Page Application](http://samples.material-design-lite.pub/template_spa/index.html)
- Routing
- Dependency injection
- [Samples, samples, samples](http://styleguide.material-design-lite.pub/#/samples)
- Theming

Visit the [website](http://www.material-design-lite.pub) for a "Quick start" or check out the [Kitchen Sink](http://styleguide.material-design-lite.pub/)

## Examples
Check out the [samples](http://styleguide.material-design-lite.pub/#/samples)

### IMPORTANT!!!
All samples-sources are now on [GH dart-material-design-lite-site](https://github.com/MikeMitterer/dart-material-design-lite-site)

## Features and bugs
Please file feature requests and bugs at the [issue tracker](https://github.com/MikeMitterer/dart-material-design-lite/issues).

## More links
- [Material Design](http://www.google.com/design/spec/material-design/introduction.html)

###License###

    Copyright 2015 Michael Mitterer (office@mikemitterer.at),
    IT-Consulting and Development Limited, Austrian Branch

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    either express or implied. See the License for the specific language
    governing permissions and limitations under the License.


If this plugin is helpful for you - please [(Circle)](http://gplus.mikemitterer.at/) me
or **star** this repo here on GitHub


[tracker]: https://github.com/MikeMitterer/dart-material-design-lite/issues
[mdlmaterial]: https://github.com/MikeMitterer/dart-material-design-lite
[mdldemo]: http://www.material-design-lite.pub
[mdlangular]: https://github.com/MikeMitterer/dart-mdl-angular
[samples]: https://github.com/MikeMitterer/dart-material-design-lite/tree/mdl/example
[promoimage]: https://github.com/MikeMitterer/dart-material-design-lite/blob/master/lib/images/mdl.mikemitterer.at-720px.jpg?raw=true
